clear

// ============
// ALL DATASETS
// ============

/* All years */

fsx *.dta
foreach file in `r(files)' {
  use `file'

  la var totpop   "Total population"
  la var urb25    "Population in cities >25k"
  la var acimp    "Acres improved farmland"
  la var farmval  "Value of farmland/improvements"
  la var equipval "Value farm implements/machinery"
  la var livstock "Value of farm livestock"

  la var farmout  "Value of all farm output"
  la var farms    "Total # Farms"
  la var farm100  "# farms 100-499 acres"
  la var farm500  "# farms 500-999 acres"
  la var farm1000 "# farms >1000 acres"
  la var mfgestab "# manufacturing establishments"
  la var mfgcap   "Manufacturing capital"
  la var mfgwages "Total annual wages manufacturing"
  la var mfgrms   "Value materials in mfg"
  la var mfgout   "Value of all manufacturing output"

  la var totout "Total Output"
  la var farmprop "Farm Proportion of Total Output"
  la var mfgprop "Mfg Proportion of Total Output"
  la var tradedpc "Tradable Ag Output per papita"
  la var ntradedpc "Non-tradable Ag Output per capita"
  la var farmpc "Ag Output per capita"
  la var mfgpc "Mfg Output per capita"
  la var party "Party Code (100=Dem, 200=Rep)"
  la var partyR "Republican (Indicator)"
  la var partyD "Democrat (Indicator)"
  
  la var id "Congressman ID"
  la var cD "Congressional District Number"
  la var state "State ICPSR code"
  la var stateName2 "State Name"
  la var name "Congressman ID"

  // save `file', replace
  saveold `file', replace
  clear
}

/* 1890s Specific Variables */
fsx h5*.*.dta
foreach file in `r(files)' {
  use `file'

  la var urb890     "Urban population 1890"
  la var acunimp    "# unimproved acres in farms"
  la var barley     "# bushels barley"
  la var barleyac   "# acres planted in barley"
  la var buckwhea   "# bushels buckwheat"
  la var buckwhac   "# acres planted in buckwheat"
  la var corn       "# bushels indian corn"
  la var cornac     "# acres planted in indian corn"
  la var oats       "# bushels oats"
  la var oatsac     "# acres planted in oats"
  la var rye        "# bushels rye"
  la var ryeac      "# acres planted in rye"
  la var wheat      "# bushels wheat"
  la var wheatac    "# acres planted in wheat"
  la var mfgcapla   "mfg capital in land"
  la var mfgcapbu   "mfg capital in buildings"
  la var mfgcapeq   "mfg capital in equipment"
  la var mfgcapca   "mfg capital in live assets/cash"
  la var mfgmisco   "total misc expenses mfg"
  la var mfgavemp   "Average # employees of all classes in mfg estabs"

  la var valfaenc   "Total value of encumbered farms"
  la var valfamtg   "Total value of mortgages on enc farms"
  la var valhoenc   "Total value of encumbered homes"
  la var valhomtg   "Total value of mortgages on enc homes"
  la var inttot     "Total interest paid on mortgages on homes/farms"
  la var inthome    "Interest paid on mortgages on homes"
  la var intfarm    "Interest paid on mortgages on farms"

  la var debt       "Value of real estate (farm and house) mortgages as a proportion of total real estate value"
  la var debtpc     "Real estate mortgage value per capita"
  la var encfarms   "Value of encumbered farms as fraction of total farm value"
  la var valmtg     "Total value of real estate mortgages"
  la var valtot     "Total value of farms and houses"

  // save `file', replace
  saveold `file', replace
  clear
}

/* 1870s Specific Variables */

fsx h3*.*.dta h4*.*.dta
foreach file in `r(files)' {
  use `file'

  la var urb870     "Urban population 1870, >2500"
  la var farmlab    "Annual agricultural wages paid, including board"
  la var mfglabor   "# hands employed mfg"

  la var homemfg    "Value home manufactures"

  la var orchard    "Value of orchard products"
  la var garden     "Value of garden products"
  la var forest     "Value of forest products"
  la var homemfg    "Value of home manufactures"

  la var acwoods    "# unimproved acres woods/forests"
  la var acunioth   "# other unimproved acres farms"

  la var wealth     "True value real and personal estate"
  la var wealthas   "Assessed value real and personal estate"

  // save `file', replace
  saveold `file', replace
  clear
  }
  


/* WIDE DATASETS */

fsx *.wide.*.dta
foreach file in `r(files)' {
  use `file'
  la var vhardprop "Votes Proportion for Hard Money"
  la var vstable "Voted consistently for hard Money"

  // save `file', replace
  saveold `file', replace
  clear
}

/* POOLED DATASETS */

fsx *.pooled.*.dta
foreach file in `r(files)' {
  use `file'
  la var vote       "Voted for hard money"

  // save `file', replace
  saveold `file', replace
  clear
}


// ************************************
// STATE LEVEL ONLY DATASETS (*.SL.DTA)
// ************************************

/* 1870s specific variables */

fsx h3*.sl.dta h4*.sl.dta
foreach file in `r(files)' {
  use `file'
  la var occtot     "Total # employed in all occupations"
  la var agemp      "Total # employed in agriculture"
  la var ppsemp     "Total # employed in prof services"
  la var ttremp     "Total # employed in trade/transport"
  la var mfgemp     "Total # employed in manufacturing"
  la var stdebt     "Total state indebtedness"
  la var newspaps   "Total newspapers"
  la var newscops   "Total newspaper copies"
  la var newscirc   "Total newspaper circulation"
  la var newsad     "# advertising publications"
  la var newsadco   "advertising publications copies"
  la var newsadci   "advertising publications circulation"
  la var newsagri   "# agricultural newspapers & periodicals"
  la var newsagco   "agricultural publication copies"
  la var newsagci   "Agricultural publications circulation"
  la var newscf     "# commerce/finance publications"
  la var newscfco   "commerce/finance publications copies"
  la var newscfci   "commerce/finance publications circulation"
  la var newspo     "# political publications"
  la var newspoco   "political publications copies"
  la var newspoci   "political publications circulation"

  // save `file', replace
  saveold `file', replace
  clear
}
